@@ -49,9 +49,10 @@ class AsyncReachClient:
 
 
 class ReachConsumerClient:
-    def __init__(self, url, exchange_name):
-        self.client = QueueAsyncClient(url, exchange_name)
+    def __init__(self, url, direct_exchange_name, fanout_exchange_name):
+        self.client = QueueAsyncClient(url, direct_exchange_name, fanout_exchange_name)
 
-    async def consume(self, callback, channel_slug):
+    async def consume(self, callback, channel_slug, listen_to_all):
         routing_key = channel_slug
-        await self.client.consume(callback, routing_key)
+        fanout = listen_to_all
+        await self.client.consume(callback, routing_key, fanout)
